searchData={"items":[{"type":"module","title":"OpentelemetryPhoenixLiveViewProcessPropagator.LiveView","doc":"`OpentelemetryPhoenixLiveViewProcessPropagator.LiveView` provides an\nextensions to the async functions in the `Phoenix.LiveView` to reduce\nboilerplate in propagating OpenTelemetry contexts across process boundaries.\n\n> #### Module Redefinement {: .info}\n>\n> This module does not redefine the `Phoenix.Liveview` module, instead\n> it provides wrappers for async functions, so this functionality will\n> not globally modify the default behavior of the `Phoenix.Liveview` module.","ref":"OpentelemetryPhoenixLiveViewProcessPropagator.LiveView.html"},{"type":"module","title":"Usage - OpentelemetryPhoenixLiveViewProcessPropagator.LiveView","doc":"Require `OpentelemetryPhoenixLiveViewProcessPropagator.LiveView` in your\n`live_view` and `live_component` macros:\n\n```elixir\ndefmodule MyAppWeb do\n  # ...\n  def live_view do\n    quote do\n      use Phoenix.LiveView,\n        layout: {MyAppWeb.Layouts, :app}\n\n      require OpentelemetryPhoenixLiveViewProcessPropagator.LiveView\n\n      unquote(html_helpers())\n    end\n  end\n\n  def live_component do\n    quote do\n      use Phoenix.LiveComponent\n\n      require OpentelemetryPhoenixLiveViewProcessPropagator.LiveView\n\n      unquote(html_helpers())\n    end\n  end\nend\n```\n\nUpdate all references to `assign_async` and `start_async` to use this module:\n\n```elixir\ndef mount(%{\"slug\" => slug}, _, socket) do\n  {:ok,\n  socket\n  |> assign(:foo, \"bar\")\n  |> OpentelemetryPhoenixLiveViewProcessPropagator.LiveView.assign_async(:org, fn -> {:ok, %{org: fetch_org!(slug)}} end)\n  |> OpentelemetryPhoenixLiveViewProcessPropagator.LiveView.assign_async([:profile, :rank], fn -> {:ok, %{profile: ..., rank: ...}} end)}\nend\n```","ref":"OpentelemetryPhoenixLiveViewProcessPropagator.LiveView.html#module-usage"},{"type":"macro","title":"OpentelemetryPhoenixLiveViewProcessPropagator.LiveView.assign_async/4","doc":"","ref":"OpentelemetryPhoenixLiveViewProcessPropagator.LiveView.html#assign_async/4"},{"type":"macro","title":"OpentelemetryPhoenixLiveViewProcessPropagator.LiveView.start_async/4","doc":"","ref":"OpentelemetryPhoenixLiveViewProcessPropagator.LiveView.html#start_async/4"},{"type":"extras","title":"Opentelemetry Phoenix LiveView Process Propagator","doc":"# Opentelemetry Phoenix LiveView Process Propagator\n\n[![Github CI](https://github.com/open-telemetrex/opentelemetry_phoenix_live_view_process_propagator/workflows/CI/badge.svg)](https://github.com/open-telemetrex/opentelemetry_phoenix_live_view_process_propagator/actions?query=workflow%3ACI)\n[![hex.pm](https://img.shields.io/hexpm/v/opentelemetry_phoenix_live_view_process_propagator.svg)](https://hex.pm/packages/opentelemetry_phoenix_live_view_process_propagator)\n\n<!-- MDOC !-->\n\nFunctions for cross-process opentelemetry context propagation in Phoenix LiveView.","ref":"README.html"},{"type":"extras","title":"Installation - Opentelemetry Phoenix LiveView Process Propagator","doc":"Add `opentelemetry_phoenix_live_view_process_propagator` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:opentelemetry_phoenix_live_view_process_propagator, \"~> 0.1\", only: [:dev, :test], runtime: false}\n  ]\nend\n```","ref":"README.html#installation"},{"type":"extras","title":"Usage - Opentelemetry Phoenix LiveView Process Propagator","doc":"Require `OpentelemetryPhoenixLiveViewProcessPropagator.LiveView` in your `live_view` and `live_component` macros:\n\n```elixir\ndefmodule MyAppWeb do\n  # ...\n  def live_view do\n    quote do\n      use Phoenix.LiveView,\n        layout: {MyAppWeb.Layouts, :app}\n\n      require OpentelemetryPhoenixLiveViewProcessPropagator.LiveView\n\n      unquote(html_helpers())\n    end\n  end\n\n  def live_component do\n    quote do\n      use Phoenix.LiveComponent\n\n      require OpentelemetryPhoenixLiveViewProcessPropagator.LiveView\n\n      unquote(html_helpers())\n    end\n  end\nend\n```\n\nUpdate the references to `assign_async` and `start_async` to use this module:application\n\n```elixir\ndef mount(%{\"slug\" => slug}, _, socket) do\n  {:ok,\n  socket\n  |> assign(:foo, \"bar\")\n  |> OpentelemetryPhoenixLiveViewProcessPropagator.LiveView.assign_async(:org, fn -> {:ok, %{org: fetch_org!(slug)}} end)\n  |> OpentelemetryPhoenixLiveViewProcessPropagator.LiveView.assign_async([:profile, :rank], fn -> {:ok, %{profile: ..., rank: ...}} end)}\nend\n```","ref":"README.html#usage"},{"type":"extras","title":"CHANGELOG","doc":"","ref":"CHANGELOG.html"},{"type":"extras","title":"v0.1.0 (2025-04-07) - CHANGELOG","doc":"","ref":"CHANGELOG.html#v0-1-0-2025-04-07"},{"type":"extras","title":"Changes - CHANGELOG","doc":"- Initial release","ref":"CHANGELOG.html#changes"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}